SystemOrganization addCategory: #'Xtreams-XtrasTests'!

!XTReadingWritingTest methodsFor: '*Xtreams-XtrasTests-crypto' stamp: 'MartinKobetic 1/16/2011 19:41'!
testReadDigest

	| content result hash in |
	content := ByteArray withAll: (1 to: 200).
	hash := #[191 214 97 229 242 76 110 243 144 172 143 238 163 155 96 32 128 47 232 63].
	self output write: content.
	in := self input hashing: 'SHA1'.
	[	result := in read: content size
	] ensure: [ in close ].
	self assert: in digest = hash.
	self assert: result = content.! !

!XTReadingWritingTest methodsFor: '*Xtreams-XtrasTests-crypto' stamp: 'MartinKobetic 1/16/2011 19:41'!
testReadDigestLong

	| content result hash in |
	content := ByteArray new: 32769.
	1 to: content size do: [:index | content at: index put: index \\ 256].
	hash := #[202 69 13 60 129 209 112 134 7 155 163 187 244 181 192 223 248 50 178 245].

	self	timeout: 1 seconds
		server:	[self output write: content. true]
		client:	[
			in := self input hashing: 'SHA1'.
			[result := in read: content size] ensure: [in close].
			in digest = hash and: [result = content]]! !

!XTReadingWritingTest methodsFor: '*Xtreams-XtrasTests-crypto' stamp: 'MartinKobetic 1/16/2011 22:57'!
testReadHMACDigest

	| content result hash in key |
	content := ByteArray withAll: (1 to: 200).
	key := ByteArray withAll: (1 to: 50).
	hash := #[150 200 234 170 46 39 176 69 56 77 242 24 192 159 25 188 216 212 251 50].
	self output write: content.
	in := self input hashing: 'SHA1' key: key.
	[	result := in read: content size
	] ensure: [ in close ].
	self assert: in digest = hash.
	self assert: result = content.! !

!XTReadingWritingTest methodsFor: '*Xtreams-XtrasTests-crypto' stamp: 'MartinKobetic 1/16/2011 19:41'!
testWriteDigest

	| content result out hash |
	content := ByteArray withAll: (1 to: 200).
	hash :=  #[191 214 97 229 242 76 110 243 144 172 143 238 163 155 96 32 128 47 232 63].
	out := self output hashing: 'SHA1'.
	[ out write: content ] ensure: [ out close ].
	self assert: out digest = hash.
	result := self input read: 200.
	self assert: result = content.! !

!XTReadingWritingTest methodsFor: '*Xtreams-XtrasTests-crypto' stamp: 'MartinKobetic 1/16/2011 19:42'!
testWriteDigestLong

	| content result out hash |
	content := ByteArray new: 32769.
	1 to: content size do: [:index | content at: index put: index \\ 256].
	hash := #[202 69 13 60 129 209 112 134 7 155 163 187 244 181 192 223 248 50 178 245].

	self timeout: 1000 milliseconds
		server:	[
			out := self output hashing: 'SHA1'.
			[ out write: content ] ensure: [ out close ].
			out digest = hash]
		client:	[
			result := self input read: content size.
			result = content]! !

!XTReadingWritingTest methodsFor: '*Xtreams-XtrasTests-crypto' stamp: 'MartinKobetic 1/16/2011 22:57'!
testWriteHMACDigest

	| content result out hash key |
	content := ByteArray withAll: (1 to: 200).
	key := ByteArray withAll: (1 to: 50).
	hash := #[150 200 234 170 46 39 176 69 56 77 242 24 192 159 25 188 216 212 251 50].
	out := self output hashing: 'SHA1' key: key.
	[ out write: content ] ensure: [ out close ].
	self assert: out digest = hash.
	result := self input read: 200.
	self assert: result = content.! !

TestCase subclass: #XTHMACTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-XtrasTests'!

!XTHMACTest methodsFor: 'tests' stamp: 'MartinKobetic 1/16/2011 19:21'!
testMD5
	
	| hash contents digest key |
	hash := XTHMAC new.
	key := 'Open sesame!!'.
	[hash algorithm: 'md5' key: key.
	contents := 'Message in the bottle!!'.
	hash updateFrom: contents.
	digest := hash finish.
	self
		assert:
			digest = #[115 209 90 58 172 75 129 194 172 139 82 10 55 52 62 127].
	hash reset.
	hash updateFrom: contents.
	digest := hash finish.
	self
		assert:
			digest = #[115 209 90 58 172 75 129 194 172 139 82 10 55 52 62 127]]
		ensure: [hash release]! !

!XTHMACTest methodsFor: 'tests' stamp: 'MartinKobetic 1/16/2011 19:21'!
testSHA
	
	| hash contents digest key |
	hash := XTHMAC new.
	key := 'Open sesame!!'.
	[hash algorithm: 'sha1' key: key.
	contents := 'Message in the bottle!!'.
	hash updateFrom: contents.
	digest := hash finish.
	self
		assert:
			digest =
					#[119 3 83 24 46 4 34 141 164 213 29 55 17 246 191 49 8 52 142 242].
	hash reset.
	hash updateFrom: contents.
	digest := hash finish.
	self
		assert:
			digest =
					#[119 3 83 24 46 4 34 141 164 213 29 55 17 246 191 49 8 52 142 242]]
		ensure: [hash release]! !

!XTHMACTest methodsFor: 'tests' stamp: 'MartinKobetic 1/16/2011 19:22'!
testSHA256
	
	| hash contents digest key |
	hash := XTHMAC new.
	key := 'Open sesame!!'.
	[hash algorithm: 'sha256' key: key.
	contents := 'Message in the bottle!!'.
	hash updateFrom: contents.
	digest := hash finish.
	self
		assert:
			digest =
					#[15 84 236 94 191 167 4 195 142 34 221 194 98 235 173 244 51 180 227 233 245 49 171 78 173 128 177 107 123 16 100 43].
	hash reset.
	hash updateFrom: contents.
	digest := hash finish.
	self
		assert:
			digest =
					#[15 84 236 94 191 167 4 195 142 34 221 194 98 235 173 244 51 180 227 233 245 49 171 78 173 128 177 107 123 16 100 43]]
		ensure: [hash release]! !

TestCase subclass: #XTHashTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-XtrasTests'!

!XTHashTest methodsFor: 'tests' stamp: 'MartinKobetic 1/16/2011 19:21'!
testMD5
	
	| hash contents digest |
	hash := XTHash new.
	[hash algorithm: 'md5'.
	contents := 'Message in the bottle!!'.
	hash updateFrom: contents.
	digest := hash finish.
	self
		assert:
			digest = #[65 87 107 237 233 250 154 151 62 208 45 46 45 66 229 159]]
		ensure: [hash release]! !

!XTHashTest methodsFor: 'tests' stamp: 'MartinKobetic 1/16/2011 19:21'!
testSHA
	
	| hash contents digest |
	hash := XTHash new.
	[hash algorithm: 'sha1'.
	contents := 'Message in the bottle!!'.
	hash updateFrom: contents.
	digest := hash finish.
	self
		assert:
			digest =
					#[135 14 150 31 117 2 161 137 130 12 126 19 22 44 107 40 138 248 165 42]]
		ensure: [hash release]! !

!XTHashTest methodsFor: 'tests' stamp: 'MartinKobetic 1/16/2011 19:21'!
testSHA256
	
	| hash contents digest |
	hash := XTHash new.
	[hash algorithm: 'sha256'.
	contents := 'Message in the bottle!!'.
	hash updateFrom: contents.
	digest := hash finish.
	self
		assert:
			digest =
					#[58 81 37 196 206 59 64 114 113 49 63 210 28 86 86 11 13 156 83 203 29 220 121 151 105 8 240 98 147 236 180 239]]
		ensure: [hash release]! !

!XTRingBufferReadingWritingTest methodsFor: '*Xtreams-XtrasTests-crypto' stamp: 'MartinKobetic 1/16/2011 19:44'!
testReadDigestLong

	"Not a test we bother doing on a small ring buffer"! !

!XTRingBufferReadingWritingTest methodsFor: '*Xtreams-XtrasTests-crypto' stamp: 'MartinKobetic 1/16/2011 19:44'!
testWriteDigestLong

	"Not a test we bother doing on a small ring buffer"! !
